@@ -745,6 +745,7 @@ def hash(value):
         self.assertEqual(repr(obj), repr(None))
         self.assertEqual(format(obj), str(None))
         self.assertEqual(format(obj, "%F"), str(None))
+
         self.assertIs(obj.attr, obj)
         self.assertIs(obj["key"], obj)
         self.assertIs(obj(), obj)
@@ -752,6 +753,17 @@ def hash(value):
         self.assertIs(obj(foo="bar"), obj)
         self.assertEqual(util.json_dumps(obj), "null")
 
+        self.assertLess(obj, "foo")
+        self.assertLessEqual(obj, None)
+        self.assertFalse(obj == obj)
+        self.assertTrue(obj != obj)
+        self.assertGreater(123, obj)
+        self.assertGreaterEqual(1.23, obj)
+
+        mapping = {}
+        mapping[obj] = 123
+        self.assertIn(obj, mapping)
+
         i = 0
         for _ in obj:
             i += 1
